/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Atari TT (USA) keyboard
 * By Mats Wichmann <mats@alruna.com>
 */

static const KeyCode tt_codes [] = {

  /* Row 0 */
  67, 68, 69, 70, 71, 72, 73, 74, 75, 76,

  /* Row 2 */
  9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 49, 22,
  106, 105,
  107, 108, 109, 110,
  
  /* Row 3 */
  23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
  91,
  90, 80, 79,
  111, 112, 113, 82,

  /* Row 4 */
  37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 36, 51,
  83, 88, 85,
 114, 115, 116, 86,
  
  /* Row 5 */
  50, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62,
  117, 118, 119, 122,

  /* Row 6 */
  64, 65, 66,
  120, 121
};
